@@ -255,7 +255,7 @@ impl From<Address> for Component {
 
 #[cfg(feature = "read_write")]
 impl TryFrom<Component> for Address {
-    type Error = Box<dyn std::error::Error>;
+    type Error = FromComponentError;
 
     fn try_from(mut comp: Component) -> Result<Self, Self::Error> {
         lazy_static! {
@@ -286,15 +286,17 @@ impl TryFrom<Component> for Address {
 
                     // Checks that it gives two values
                     if split.len() != 2 {
-                        return Err(Box::new(
-                            FromComponentError::NotEnoughValues,
-                        ));
+                        return Err(FromComponentError::NotEnoughValues);
                     }
 
                     // Build the Geo
                     Some(Geo {
-                        longitude: split[0].parse()?,
-                        latitude: split[1].parse()?,
+                        longitude: split[0]
+                            .parse()
+                            .map_err(FromComponentError::ParseFloatError)?,
+                        latitude: split[1]
+                            .parse()
+                            .map_err(FromComponentError::ParseFloatError)?,
                     })
                 }
                 None => None,
