@@ -116,7 +116,7 @@ impl From<ContactInformation> for Component {
 
 #[cfg(feature = "read_write")]
 impl std::convert::TryFrom<Component> for ContactInformation {
-    type Error = Box<dyn std::error::Error>;
+    type Error = FromComponentError;
 
     fn try_from(mut comp: Component) -> Result<Self, Self::Error> {
         Ok(Self {
@@ -124,10 +124,9 @@ impl std::convert::TryFrom<Component> for ContactInformation {
                 .parameters
                 .remove("PID")
                 .unwrap_or(format!("{}", rand::random::<u64>() % 100)),
-            pref: comp
-                .parameters
-                .remove("PREF")
-                .map_or(Ok(0), |x| x.parse())?,
+            pref: comp.parameters.remove("PREF").map_or(Ok(0), |x| {
+                x.parse().map_err(FromComponentError::ParseIntError)
+            })?,
             value: comp
                 .values
                 .pop()
