@@ -144,7 +144,7 @@ impl From<DateTime> for Component {
 
 #[cfg(feature = "read_write")]
 impl TryFrom<Component> for DateTime {
-    type Error = Box<dyn std::error::Error>;
+    type Error = FromComponentError;
 
     fn try_from(comp: Component) -> Result<Self, Self::Error> {
         // Define some regexes which could parse a date.
@@ -196,32 +196,56 @@ impl TryFrom<Component> for DateTime {
         Ok(Self {
             year: capture
                 .name("year")
-                .map(|x| x.as_str().parse())
+                .map(|x| {
+                    x.as_str()
+                        .parse()
+                        .map_err(FromComponentError::ParseIntError)
+                })
                 .transpose()?
                 .unwrap_or_default(),
             month: capture
                 .name("month")
-                .map(|x| x.as_str().parse())
+                .map(|x| {
+                    x.as_str()
+                        .parse()
+                        .map_err(FromComponentError::ParseIntError)
+                })
                 .transpose()?
                 .unwrap_or_default(),
             day: capture
                 .name("day")
-                .map(|x| x.as_str().parse())
+                .map(|x| {
+                    x.as_str()
+                        .parse()
+                        .map_err(FromComponentError::ParseIntError)
+                })
                 .transpose()?
                 .unwrap_or_default(),
             hour: capture
                 .name("hour")
-                .map(|x| x.as_str().parse())
+                .map(|x| {
+                    x.as_str()
+                        .parse()
+                        .map_err(FromComponentError::ParseIntError)
+                })
                 .transpose()?
                 .unwrap_or_default(),
             minute: capture
                 .name("minute")
-                .map(|x| x.as_str().parse())
+                .map(|x| {
+                    x.as_str()
+                        .parse()
+                        .map_err(FromComponentError::ParseIntError)
+                })
                 .transpose()?
                 .unwrap_or_default(),
             second: capture
                 .name("second")
-                .map(|x| x.as_str().parse())
+                .map(|x| {
+                    x.as_str()
+                        .parse()
+                        .map_err(FromComponentError::ParseIntError)
+                })
                 .transpose()?
                 .unwrap_or_default(),
         })
