@@ -11,32 +11,35 @@
 //! With the `read_write` feature you can have native support for serialisation
 //! and deserialisation, to VCard. This is achieved as follows:
 //!
-//! ```rust
+//! ```no_run
 //! use contack::Contact;
 //! use contack::read_write::vcard::VCard;
 //! use std::fs::File;
 //! use std::io::prelude::*;
 //! use std::convert::TryInto;
+//! use std::error::Error;
 //!
 //! fn main() -> Result<(), Box<dyn Error>> {
 //!     // Load a VCard file
-//!     let vcard = String::new();
+//!     let mut vcard = String::new();
 //!     File::open("my_card.vcard")?.read_to_string(&mut vcard)?;
 //!     
 //!     // Serialise it
 //!     let vcard: VCard = vcard.parse()?;
 //!     
 //!     // Convert it to a contact
-//!     let contact: Contact = vcard.try_into()?;
+//!     let mut contact: Contact = vcard.try_into()?;
 //!     
 //!     // Make some changes
-//!     contact.role = Some("Being a handy example.");
+//!     contact.role = Some("Being a handy example.".to_string());
 //!     
 //!     // Convert it to a VCard representation.
-//!     let vcard: VCard = vcard.into();
+//!     let vcard: VCard = contact.into();
 //!     
 //!     // Print it to the stdout
 //!     println!("{}", vcard.to_string());
+//!
+//!     Ok(())
 //! }
 //! ```
 //!
@@ -66,8 +69,7 @@ pub mod date_time;
 pub mod name;
 pub mod org;
 pub mod uri;
-#[cfg(feature = "to_vcard")]
-pub mod vcard;
+pub mod gender;
 
 #[cfg(feature = "lazy_static")]
 #[macro_use]
@@ -112,6 +114,7 @@ pub use {
     name::Name,
     org::Org,
     uri::Uri,
+    gender::{Gender, Sex}
 };
 
 /// This is the base structure to hold all contact details
@@ -162,6 +165,9 @@ pub struct Contact {
     /// The Contact's contact information
     pub contact_information: Vec<contact_information::ContactInformation>,
 
+    /// The contact's sex and gender
+    pub gender: Option<gender::Gender>,
+
     /*
      * Deliver Addressing Properties
      */
@@ -182,18 +188,8 @@ impl Contact {
     pub fn new(name: name::Name) -> Self {
         Self {
             name,
-            nickname: None,
-            anniversary: None,
-            bday: None,
-            photo: None,
-            title: None,
-            role: None,
-            org: None,
-            logo: None,
-            contact_information: Vec::new(),
-            work_address: None,
-            home_address: None,
             uid: uuid::Uuid::new_v4().to_string(),
+            ..Self::default()
         }
     }
 }
@@ -292,6 +288,11 @@ impl From<Contact> for read_write::vcard::VCard {
             vec.push(ci.into());
         }
 
+        // Gender
+        if let Some(gender) = c.gender {
+            vec.push(gender.into());
+        }
+
         // Work Address
         if let Some(adr) = c.work_address {
             let mut adr: Component = adr.into();
@@ -314,7 +315,7 @@ impl From<Contact> for read_write::vcard::VCard {
 
 #[cfg(feature = "read_write")]
 impl TryFrom<read_write::vcard::VCard> for Contact {
-    type Error = Box<dyn std::error::Error>;
+    type Error = FromComponentError;
 
     fn try_from(vcard: read_write::vcard::VCard) -> Result<Self, Self::Error> {
         // Create a contact - with no name (for now)
@@ -386,6 +387,8 @@ impl TryFrom<read_write::vcard::VCard> for Contact {
                     contact.contact_information.push(comp.try_into()?)
                 }
 
+                "GENDER" => contact.gender = Some(comp.try_into()?),
+
                 // Addresses.
                 //
                 // Note that if ambigouous it is assumed that an address
