@@ -133,7 +133,7 @@ impl FromStr for Component {
 
         let caps = match REGEX.captures(&string) {
             Some(caps) => caps,
-            None => return Err(ComponentParseError::Invalid),
+            None => return Err(ComponentParseError::Invalid(string.clone())),
         };
 
         return Ok(Self {
