@@ -1,14 +1,14 @@
 use std::error::Error;
 use std::fmt;
 
-#[derive(Eq, PartialEq, Copy, Clone, Hash, Debug)]
-pub enum ComponentParseError {
+#[derive(Eq, PartialEq, Clone, Hash, Debug)]
+pub enum ComponentParseError  {
     /// A component has no name
     NoName,
     /// A component has no value
     NoValue,
     /// A component is invalid
-    Invalid,
+    Invalid(String),
 }
 
 impl fmt::Display for ComponentParseError {
@@ -18,8 +18,8 @@ impl fmt::Display for ComponentParseError {
             Self::NoValue => {
                 write!(f, "The VCard component contained no value")
             }
-            Self::Invalid => {
-                write!(f, "The VCard component contained invalid formatting.")
+            Self::Invalid(s) => {
+                write!(f, "The VCard component contained invalid formatting.\n{}", s)
             }
         }
     }
