@@ -9,6 +9,8 @@ table! {
         nickname -> Nullable<Text>,
         anniversary -> Nullable<Timestamp>,
         bday -> Nullable<Timestamp>,
+        gender_gender -> Nullable<Text>,
+        gender_sex -> Nullable<Text>,
         photo_uri -> Nullable<Text>,
         photo_bin -> Nullable<Bytea>,
         photo_mime -> Nullable<Text>,
