@@ -39,6 +39,8 @@ pub struct SqlContact {
     pub nickname: Option<String>,
     pub anniversary: Option<chrono::NaiveDateTime>,
     pub bday: Option<chrono::NaiveDateTime>,
+    pub gender_gender: Option<String>,
+    pub gender_sex: Option<String>,
     pub photo_uri: Option<String>,
     pub photo_bin: Option<Vec<u8>>,
     pub photo_mime: Option<String>,
@@ -96,7 +98,7 @@ impl std::convert::TryFrom<SqlContact> for Contact {
                 None => None,
                 Some(x) => Some(DateTime::try_from(x)?),
             },
-
+        
             // Photo
             photo: Uri::try_from_sql_raw((
                 them.photo_uri,
@@ -111,6 +113,23 @@ impl std::convert::TryFrom<SqlContact> for Contact {
             // Role
             role: them.role,
 
+            // Gender
+            gender: if them.gender_gender.is_some() || them.gender_sex.is_some() {
+                Some(Gender {
+                    sex: match them.gender_sex.as_deref() {
+                        None | Some("N") => None,
+                        Some("M") => Some(Sex::Male),
+                        Some("F") => Some(Sex::Female),
+                        Some("O") => Some(Sex::Other),
+                        Some("U") => Some(Sex::Unknown),
+                        _ => Err("Invalid Value for Gender")?,
+                    },
+                    identity: them.gender_gender
+                })
+            } else {
+                None
+            },
+
             // Org
             org: {
                 if them.org_org.is_some()
@@ -221,6 +240,10 @@ impl TryFrom<Contact> for SqlContact {
                 None => None,
             },
 
+            // Gender
+            gender_sex: them.gender.as_ref().map(|x| x.sex.map(char::from).unwrap_or('N').to_string()),
+            gender_gender: them.gender.and_then(|x| x.identity),
+
             // Gets the photo properties.
             photo_uri,
             photo_bin,
