@@ -105,7 +105,7 @@ impl From<Uri> for Component {
 
 #[cfg(feature = "read_write")]
 impl TryFrom<Component> for Uri {
-    type Error = Box<dyn std::error::Error>;
+    type Error = FromComponentError;
 
     fn try_from(comp: Component) -> Result<Self, Self::Error> {
         // Generate a regex, which can be used to grab base64 data.
@@ -132,10 +132,11 @@ impl TryFrom<Component> for Uri {
                             comp.values[1]
                                 .get(1)
                                 .ok_or(FromComponentError::NotEnoughValues)?,
-                        )?,
+                        )
+                        .map_err(FromComponentError::Base64DecodeError)?,
                     })
                 } else {
-                    Err(Box::new(FromComponentError::InvalidRegex))
+                    Err(FromComponentError::InvalidRegex)
                 }
             }
             1 => Ok(Self::Url {
@@ -145,7 +146,7 @@ impl TryFrom<Component> for Uri {
                     .to_string(),
             }),
             // Don't know how to handle
-            _ => Err(Box::new(FromComponentError::NotEnoughValues)),
+            _ => Err(FromComponentError::NotEnoughValues),
         }
     }
 }
